|License| |PyPI version| |Documentation Status|

SMETANA
=======

Species METabolic interaction ANAlysis (SMETANA) is a python-based
command line tool to analyse microbial communities.

It takes as input a microbial communtity (from a collection of
genome-scale metabolic models in SBML format) and computes of several
metrics that describe the potential for cross-feeding interactions
between community members.

Documentation
~~~~~~~~~~~~~

For more details please check: http://smetana.readthedocs.io/

Installation
~~~~~~~~~~~~

Can be easily installed using **pip**:

::

    pip install smetana

Citing SMETANA:
~~~~~~~~~~~~~~~

The algorithms here implemented have been previously described in:
`Zelezniak et al, PNAS
(2015) <http://www.pnas.org/content/112/20/6449.short>`__.

.. |License| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
   :target: https://opensource.org/licenses/Apache-2.0
.. |PyPI version| image:: https://badge.fury.io/py/smetana.svg
   :target: https://badge.fury.io/py/smetana
.. |Documentation Status| image:: http://readthedocs.org/projects/smetana/badge/?version=latest
   :target: http://smetana.readthedocs.io/en/latest/?badge=latest
